from __future__ import annotations

import io
import os

import setuptools

# Package metadata.

name = 'neucli'
description = 'Neulabs cli'

# Setup boilerplate below this line.
package_root = os.path.abspath(os.path.dirname(__file__))

version = {}
with open(os.path.join(package_root, 'neucli/version.py')) as fp:
    exec(fp.read(), version)
version = version['__version__']

readme_filename = os.path.join(package_root, 'README.md')
with io.open(readme_filename, encoding='utf-8') as readme_file:
    readme = readme_file.read()

setuptools.setup(
    name=name,
    version=version,
    description=description,
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Neulabs',
    author_email='tech@neulabs.com',
    license='Apache 2.0',
    url='https://github.com/neulabscom/neulabs-cli',
    classifiers=[
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.8',
    include_package_data=True,
    zip_safe=False,
    packages=setuptools.find_packages(exclude=['tests*', 'lib*']),
    scripts=['bin/neucli'],
)



#!/usr/bin/env python3
from __future__ import annotations

import argparse
import subprocess
import sys


def argsinstance(parser=None):
    def _ecr_login(parser):
        parser_ecr_login = parser.add_parser(
            'ecr-login', help='Login to ECR repository')

        parser_ecr_login.add_argument(
            '--account-id',
            required=True,
            default=None,
            type=str,
            help='Account id ecr',
        )
        parser_ecr_login.add_argument(
            '--region',
            required=True,
            default=None,
            type=str,
            help='AWS region repository',
        )
        parser_ecr_login.add_argument(
            '--profile',
            required=False,
            default=None,
            type=str,
            help='AWS profile',
        )

    if parser is None:
        parser = argparse.ArgumentParser()

    subparsers = parser.add_subparsers(
        help='Help for command', dest='subcommand')
    _ecr_login(subparsers)

    return parser


def ecr_login_action(args):
    profile = '--profile ' + args.profile if args.profile else ''
    command = f'aws {profile} ecr get-login-password --region {args.region} | docker login --username AWS --password-stdin {args.account_id}.dkr.ecr.{args.region}.amazonaws.com'

    subprocess.check_call(command, shell=True)


def main(args=None):
    try:
        if args is None:
            args = argsinstance().parse_args()

        if args.subcommand == 'ecr-login':
            ecr_login_action(args)
    except KeyboardInterrupt:
        return 0


if __name__ == '__main__':
    sys.exit(main())
